@@ -8,7 +8,6 @@ use strict;
 our @www_whois = qw(
     VN
     AC
-    BZ
     TJ
     CM
 );
@@ -156,6 +155,7 @@ our %servers = qw(
     BJ  whois.nic.bj
     BR  whois.registro.br
     CA  whois.cira.ca
+    CD  whois.nic.cd
     CH  whois.nic.ch
     CI  whois.nic.ci
     CL  Whois.nic.cl
@@ -176,6 +176,7 @@ our %servers = qw(
     GG  whois.channelisles.net
     GI  whois2.afilias-grs.net
     GS  whois.nic.gs
+    GY  whois.registry.gy
     HU  whois.nic.hu
     HK  whois.hkirc.hk
     HM  whois.registry.hm
@@ -186,6 +187,7 @@ our %servers = qw(
     IM  whois.nic.im
     IN  whois.inregistry.net
     IO  whois.nic.io
+    IR  whois.nic.ir
     IS  whois.isnic.is
     IT  whois.nic.it
     JE  whois.channelisles.net
@@ -201,8 +203,11 @@ our %servers = qw(
     LT  whois.domreg.lt
     LU  whois.dns.lu
     LV  whois.nic.lv
+    LY  whois.nic.ly
+    MA  whois.iam.net.ma
     MC  whois.ripe.net
     MD  whois.nic.md
+    ME  whois.nic.me
     MG  whois.nic.mg
     MN  whois2.afilias-grs.net
     MS  whois.nic.ms
@@ -220,6 +225,8 @@ our %servers = qw(
     PT  whois.dns.pt
     RE  whois.nic.re
     RO  whois.rotld.ro
+    RS  whois.rnids.rs
+    SA  whois.saudinic.net.sa
     SB  whois.nic.sb
     SC  whois2.afilias-grs.net
     SE  whois.iis.se
@@ -238,7 +245,8 @@ our %servers = qw(
     TO  whois.tonic.to
     TR  whois.nic.tr
     TW  whois.twnic.net.tw
-    UA  whois.net.ua
+    UA  whois.com.ua
+    NET.UA  whois.net.ua
     UK  whois.nic.uk
     US  whois.nic.us
     UZ  whois.cctld.uz
@@ -359,6 +367,20 @@ our %servers = qw(
     YN.CN  whois.cnnic.net.cn
     ZJ.CN  whois.cnnic.net.cn
 
+    AC.FJ   whois.domains.fj
+    BIZ.FJ  whois.domains.fj
+    COM.FJ  whois.domains.fj
+    INFO.FJ whois.domains.fj
+    MIL.FJ  whois.domains.fj
+    NAME.FJ whois.domains.fj
+    NET.FJ  whois.domains.fj
+    ORG.FJ  whois.domains.fj
+    PRO.FJ  whois.domains.fj
+
+    CO.GY   whois.registry.gy
+    COM.GY  whois.registry.gy
+    NET.GY  whois.registry.gy
+
     COM.HK  whois.hknic.net.hk
     GOV.HK  whois.hknic.net.hk
     NET.HK  whois.hknic.net.hk
@@ -371,10 +393,27 @@ our %servers = qw(
     NE.JP  whois.jprs.jp
     OR.JP  whois.jprs.jp
 
+    AC.MA   whois.iam.net.ma
+    CO.MA   whois.iam.net.ma
+    GOV.MA  whois.iam.net.ma
+    NET.MA  whois.iam.net.ma
+    ORG.MA  whois.iam.net.ma
+    PRESS.MA  whois.iam.net.ma
+
     COM.MX  whois.nic.mx
     GOB.MX  whois.nic.mx
     NET.MX  whois.nic.mx
 
+    COM.MT  whois.nic.mt
+    ORG.MT  whois.nic.mt
+    NET.MT  whois.nic.mt
+    EDU.MT  whois.nic.mt
+
+    CO.RS  whois.rnids.rs
+    ORG.RS whois.rnids.rs
+    IN.RS  whois.rnids.rs
+    EDU.RS whois.rnids.rs
+
     COM.TW  whois.twnic.net
     IDV.TW  whois.twnic.net
     NET.TW  whois.twnic.net
@@ -384,11 +423,13 @@ our %servers = qw(
     COM.UA      whois.com.ua
     ORG.UA      whois.com.ua
     BIZ.UA      whois.biz.ua
+    CO.UA       whois.co.ua
     PP.UA	whois.pp.ua
     KIEV.UA     whois.com.ua
     DN.UA       whois.dn.ua
     LG.UA       whois.lg.ua
     OD.UA       whois.od.ua
+    IN.UA       whois.in.ua
 
     AC.UK	whois.ja.net
     CO.UK   whois.nic.uk
@@ -432,6 +473,8 @@ our %servers = qw(
     BIZ.NS	whois.biz
     NAME.NS	whois.nic.name
     SO          whois.nic.so
+    BZ          whois.belizenic.bz
+    XXX         whois.nic.xxx
 );
 
 
@@ -462,9 +505,11 @@ our %codepages = (
     'whois.net.ua'       => 'koi8-u',
     'whois.com.ua'       => 'koi8-u',
     'whois.biz.ua'       => 'koi8-u',
+    'whois.co.ua'        => 'koi8-u',
     'whois.dn.ua'        => 'koi8-u',
     'whois.lg.ua'        => 'koi8-u',
     'whois.od.ua'        => 'koi8-u',
+    'whois.in.ua'        => 'koi8-u',
     'whois.jprs.jp'      => 'iso-2022-jp',
     'whois.nic.or.kr'    => 'euc-kr',
     'whois.domain.kg'    => 'cp-1251',
@@ -482,6 +527,7 @@ our %notfound = (
     'whois.reg.ru'          => '^Domain \S+ not found',
 
     'whois.com.ua'          => 'No entries found for',
+    'whois.co.ua'           => 'No entries found',
     'whois.biz.ua'          => 'No entries found',
     'whois.net.ua'            => 'No entries found for domain',
     'delta.hostmaster.net.ua' => 'No entries found for domain',
@@ -489,6 +535,7 @@ our %notfound = (
     'whois.dn.ua'             => 'No match record found',
     'whois.lg.ua'             => 'No match record found',
     'whois.od.ua'             => 'No match record found',
+    'whois.in.ua'             => 'No records found',
 
     'whois.aero'                 => '^NOT FOUND',
     'whois.nic.asia'             => '^NOT FOUND',
@@ -509,7 +556,7 @@ our %notfound = (
     'ccwhois.verisign-grs.com'   => '^No match for',
     'jobswhois.verisign-grs.com' => '^No match for',
     'tvwhois.verisign-grs.com'   => '^No match for',
-    'whois.registrypro.pro'      => '^Unknown domain',
+    'whois.registrypro.pro'      => '^No match',
     'whois.worldsite.ws'         => 'No match for',
     'whois.nic.travel'           => 'Not found: \S+',
 
@@ -524,32 +571,36 @@ our %notfound = (
     'whois.registro.br'       => 'No match for',
     'whois.registry.hm'       => 'Domain not found',
     'whois.nic.ht'            => 'Status: Not Registered',
-    'whois.cira.ca'           => '^Domain status\:\s+AVAIL',
+    'whois.cira.ca'           => '^Domain status\:\s+available',
+    'whois.nic.cd'            => 'Domain Not Found',
     'whois.nic.ch'            => '^We do not have an entry in our database matching your',
     'whois.nic.ci'            => '^Domain \S+ not found',
     'whois.nic.cl'            => '\: no existe',
     'whois.nic.cx'            => 'Status\: Not Registered',
-    'whois.nic.cz'            => 'No data found',
+    'whois.nic.cz'            => '^\% No entries found.',
     'whois.denic.de'          => 'Status\: free',
     'whois.nic.dm'            => 'Status\: Not Registered',
     'whois.dk-hostmaster.dk'  => '^No entries found for',
-    'whois.eenet.ee'          => '^NOT FOUND',
+    'whois.eenet.ee'          => '^\% No entries found',
     'whois.eu'                => '^Status:\s+AVAILABLE',
     'whois.ficora.fi'         => 'Domain not found',
+    'whois.domains.fj'        => 'The domain \S+ was not found',
     'whois.nic.fm'            => 'Status: Not Registered',
     'whois.nic.fr'            => 'No entries found',
     'whois.channelisles.net'  => 'No information found',
     'whois.nic.gs'            => 'Status: Not Registered',
-    'whois.hkirc.hk'          => '^Domain Not Found',
+    'whois.registry.gy'       => 'Status\:\s+Not Registered',
+    'whois.hkirc.hk'          => '^The domain has not been registered',
     'whois.hknic.net.hk'      => 'Domain Not Found',
     'whois.nic.hu'            => 'No match',
-    'whois.domainregistry.ie' => 'There was no match',
+    'whois.domainregistry.ie' => '^\% Not Registered',
     'whois.isoc.org.il'       => 'No data was found',
     'whois.nic.im'            => 'The domain \S+ was not found',
     'whois.inregistry.net'    => 'NOT FOUND',
     'whois.nic.io'            => 'Domain \S+ - Available',
     'whois.isnic.is'          => 'No entries found',
     'whois.nic.it'            => 'Status:\s+AVAILABLE',
+    'whois.nic.ir'            => 'No entries found',
     'whois.jprs.jp'           => 'No match',
     'whois.kenic.or.ke'       => 'No match found',
     'whois.nic.ki'            => 'Status: Not Registered',
@@ -559,22 +610,30 @@ our %notfound = (
     'whois.nic.li'            => 'We do not have an entry',
     'whois.domreg.lt'         => '^Status:\s+available',
     'whois.dns.lu'            => 'No such domain',
-    'whois.nic.lv'            => 'Nothing found',
+    'whois.nic.lv'            => 'Status\: free',
+    'whois.nic.ly'            => 'Not found',
+    'whois.iam.net.ma'        => 'No Objects Found',
     'whois.nic.md'            => 'No match for',
+    'whois.nic.me'            => 'NOT FOUND',
+	'whois.nic.mg'			  => 'Status\: Not Registered',
     'whois.nic.ms'            => 'Status\: Not Registered',
+    'whois.nic.mt'            => 'Domain is not registered',
+    'whois.nic.mu'            => 'Status\: Not Registered',
     'whois.nic.mx'            => 'Object_Not_Found',
     'whois.mynic.net.my'      => '^Domain Name \S+ does not',
     'whois.na-nic.com.na'     => '^Status\: Not Registered',
     'whois.domain-registry.nl' => '^\S+ is free',
-    'whois.norid.no'          => 'no matches',
+    'whois.norid.no'          => '^\% No match',
     'whois.nic.nu'            => '^NO MATCH for domain',
     'whois.srs.net.nz'        => '^query_status\: (500 Invalid|220 Avail)',
-    'whois.dns.pl'            => 'No information about domain',
+    'whois.dns.pl'            => 'No information available about domain name',
     'whois.nic.pm'            => 'No entries found',
-    'whois.nic.pr'            => 'No records matching',
+    'whois.nic.pr'            => 'is available for registration',
     'whois.dns.pt'            => 'no match',
     'whois.nic.re'            => 'No entries found',
     'whois.rotld.ro'          => 'No entries found',
+    'whois.rnids.rs'          => 'Domain is not registered',
+    'whois.saudinic.net.sa'   => 'No Match for',
     'whois.nic.sb'            => 'Status: Not Registered',
     'whois.iis.se'            => '^\S+ not found',
     'whois.nic.net.sg'        => '^Domain Not Found',
@@ -593,6 +652,7 @@ our %notfound = (
     'whois.nic.uk'            => 'No match for',
     'whois.ja.net'            => '^No such domain',
     'whois.nic.us'            => '^Not found',
+    'whois.cctld.uz'          => 'not found in database',
     'whois.nic.ve'            => 'No match for',
     'whois.nic.wf'            => 'No entries found',
     'whois.nic.yt'            => 'No entries found',
@@ -657,6 +717,8 @@ our %notfound = (
 
     # for VN | TJ | CM zones
     'www_whois'                 => '(Available|no records found|is free|Not Registered)',
+
+    'whois.nic.xxx'             => 'NOT FOUND',
 );
 
 our %strip = (
@@ -2081,6 +2143,24 @@ our %strip = (
         '^BelizeNIC registrar reserves the right to modify these terms at any time.',
         '^By submitting this query, you agree to abide by these terms.',
     ],
+    'whois.nic.xxx' => [
+        '^Access to the .XXX WHOIS information is provided to assist persons in',
+        '^determining the contents of a domain name registration record in the',
+        '^ICM Registry database. The data in this record is provided by',
+        '^ICM Registry for informational purposes only, and ICM does not',
+        '^guarantee its accuracy. This service is intended only for query-based',
+        '^access. You agree that you will use this data only for lawful purposes',
+        '^and that, under no circumstances will you use this data to',
+        '^enable, or otherwise support the transmission by e-mail, telephone, or',
+        '^facsimile of mass unsolicited, commercial advertising or solicitations',
+        '^to entities other than the data recipient',
+        '^\(b\) enable high volume, automated, electronic processes that send',
+        '^queries or data to the systems of Registry Operator, a Registrar, or',
+        '^ICM except as reasonably necessary to register domain names or',
+        '^modify existing registrations. All rights reserved. ICM reserves',
+        '^the right to modify these terms at any time. By submitting this query,',
+        '^you agree to abide by this policy.',
+    ],
 );
 
 our %exceed = (
@@ -2097,6 +2177,10 @@ our %exceed = (
     'whois.pir.org'  => 'WHOIS LIMIT EXCEEDED',
     'whois.nic.ms'   => 'Look up quota exceeded',
     'whois.nic.gs'   => 'look up quota exceeded',
+    'whois.nic.tl'   => 'Lookup quota exceeded',
+    'whois.nic.mg'   => 'Lookup quota exceeded',
+    'whois.nic.li'   => 'You have exceeded this limit',
+    'whois.nic.ch'   => 'You have exceeded this limit',
 );
 
 our $default_ban_time = 60;
